@@ -1,7 +1,10 @@
 package DBIx::Class::Helper::JoinTable;
-our $VERSION = '2.00200';
+our $VERSION = '2.002001';
 
 use parent 'DBIx::Class::Helper::Row::JoinTable';
+use Carp::Clan;
+carp 'This module is deprecated!  Pleause use the namespaced version instead!' if $VERSION >= 3;
+croak 'This module is deprecated!  Pleause use the namespaced version instead!' if $VERSION >= 4;
 
 # ABSTRACT: (DEPRECATED) Easily set up join tables with DBIx::Class
 
@@ -17,7 +20,7 @@ DBIx::Class::Helper::JoinTable - (DEPRECATED) Easily set up join tables with DBI
 
 =head1 VERSION
 
-version 2.00200
+version 2.002001
 
 =head1 DESCRIPTION
 
